import os
import ybc_speech as speech
import sys
from pydub import AudioSegment
from ybc_exception import *
os.environ['PATH'] = '/usr/bin'


def analysis(filename):
    """
    功能：分析微信语音内容转换成文字。
    参数 filename: 微信语音文件名。
    返回：转换成的文字
    """
    if not isinstance(filename, str):
        raise ParameterTypeError(sys._getframe().f_code.co_name, "'filename'")
    if not filename:
        raise ParameterValueError(sys._getframe().f_code.co_name, "'filename'")

    try:
        sound = AudioSegment.from_mp3(filename).set_frame_rate(16000)
        sound.export('tmp.wav', format = "wav")
        text = speech.voice2text('tmp.wav')
        return text
    except Exception as e:
        raise InternalError(e, 'ybc_switch')


if __name__ == '__main__':
    print(analysis('1.mp3'))


import unittest
from ybc_switch import *


class MyTestCase(unittest.TestCase):
    def test_analysis(self):
        self.assertEqual('天气', analysis('1.mp3'))
        self.assertEqual('天气', analysis('tmp.wav'))

    def test_analysis_error(self):
        with self.assertRaises(InternalError):
            analysis('cup.jpg')

    def test_analysis_typeError(self):
        with self.assertRaisesRegex(ParameterTypeError, "^参数类型错误 : 调用analysis方法时，'filename'参数类型错误。$"):
            analysis(123)

    def test_analysis_valueError(self):
        with self.assertRaisesRegex(ParameterValueError, "^参数数值错误 : 调用analysis方法时，'filename'参数不在允许范围内。$"):
            analysis('')


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python

from distutils.core import setup

setup(name='ybc_switch',
      version='1.0.4',
      description='Switch audio files.',
      long_description='Switch audio files.',
      author='hurs',
      author_email='hurs@fenbi.com',
      keywords=['python', 'switch', 'audio'],
      url='http://pip.zhenguanyu.com/',
      packages=['ybc_switch'],
      package_data={'ybc_switch': ['*.py', '1.mp3', 'tmp.wav']},
      license='MIT',
      requires=['pydub', 'ybc_exception']
     )